@@ -1,6 +1,6 @@
-from numpy.linalg import eigh
-from numpy.linalg import svd
-from numpy import logical_not
+from numpy import asarray, logical_not
+from numpy.linalg import eigh, svd
+
 from .. import _epsilon as epsilon
 
 
@@ -41,6 +41,7 @@ def economic_qs_linear(G):
     Returns:
         tuple: ``((Q0, Q1), S0)``.
     """
+    G = asarray(G, float)
     (Q, Ssq, _) = svd(G, full_matrices=True)
     S0 = Ssq**2
     rank = len(S0)
